summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/select.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/select.h')
-rw-r--r--include/ruby/impl/intern/select.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/intern/select.h b/include/ruby/impl/intern/select.h
index bdbb289b49..51272af219 100644
--- a/include/ruby/impl/intern/select.h
+++ b/include/ruby/impl/intern/select.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_SELECT_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_SELECT_H
+#ifndef RBIMPL_INTERN_SELECT_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_SELECT_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -41,12 +41,12 @@
# define rb_fd_resize(n, f) ((void)(f))
#endif
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
struct timeval;
int rb_thread_fd_select(int, rb_fdset_t *, rb_fdset_t *, rb_fdset_t *, struct timeval *);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_SELECT_H */
+#endif /* RBIMPL_INTERN_SELECT_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file